# Changelog

## [0.2.0] - 2020-05-26

- Convert Python code to Cython
- Add utilities to extract terrain from images and to rescale positions
- Add benchmarks
- Add tests, explain rounding errors between `pymartini` and Martini in README.

## [0.1.0] - 2020-05-26

- Initial release
